@@ -1,3 +1,5 @@
+from typing import Any
+
 from algora.api.service.project.package.model import ProjectPackageRequest
 
 
@@ -13,6 +15,12 @@ def _get_project_packages_request_info() -> dict:
     }
 
 
+def _search_project_packages_request_info(name: str, version: str) -> dict:
+    return {
+        'endpoint': f"config/project/package/search?name={name}&version={version}"
+    }
+
+
 def _create_project_package_request_info(request: ProjectPackageRequest) -> dict:
     return {
         'endpoint': f"config/project/package",
