@@ -6,7 +6,7 @@ import json
 from abc import ABC
 from datetime import date, datetime, tzinfo
 
-from pydantic import BaseModel, create_model
+from pydantic import BaseModel
 
 from algora.common.date import date_to_timestamp, datetime_to_timestamp
 
@@ -34,7 +34,7 @@ class Base(ABC, BaseModel):
         Returns:
             str: Class name
         """
-        return cls.__name__.lower()
+        return cls.__name__
 
     def request_dict(self) -> dict:
         """
