@@ -3,5 +3,5 @@ Common decorators.
 """
 from algora.common.decorators.authorization import authenticated_request, async_authenticated_request
 from algora.common.decorators.data import data_request, async_data_request
-from algora.common.decorators.serializable import serializable
+from algora.common.decorators.serializable import serializable, serializable_base_class
 from algora.common.decorators.partitioned_cache import partitioned_cached
