@@ -70,7 +70,9 @@ async def __async_put_request(
     Returns:
         Response: HTTP response object
     """
-    data = data if data is None else data.update({"files": files})
+    if files:
+        data = files
+
     async with aiohttp.ClientSession() as session:
         async with session.put(
                 url=f"{config.get_url(url_key)}/{endpoint}",
@@ -112,7 +114,9 @@ async def __async_post_request(
     Returns:
         Response: HTTP response object
     """
-    data = data if data is None else data.update({"files": files})
+    if files:
+        data = files
+
     async with aiohttp.ClientSession() as session:
         async with session.post(
                 url=f"{config.get_url(url_key)}/{endpoint}",
